"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateB2CTokenClaims = exports.validateTokenClaims = void 0;
function validateTokenClaims(tokenPayload, { applicationId, audience, scopes, tenantId }) {
    // tenantId
    if (!tokenPayload.tid) {
        throw new Error('The token\'s payload does not contain "tid" property');
    }
    const isValidTenantId = tokenPayload.tid === tenantId;
    if (!isValidTenantId) {
        throw new Error("The token's payload contains different tenantId");
    }
    // applicationId
    if (!tokenPayload.appid) {
        throw new Error('The token\'s payload does not contain "appid" property');
    }
    const isValidApplicationId = tokenPayload.appid === applicationId;
    if (!isValidApplicationId) {
        throw new Error("The token's payload contains different applicationId");
    }
    // audience
    if (!tokenPayload.aud) {
        throw new Error('The token\'s payload does not contain "aud" property');
    }
    const isValidAudience = tokenPayload.aud === audience;
    if (!isValidAudience) {
        throw new Error("The token's payload contains different audience");
    }
    // security token service
    if (!tokenPayload.iss) {
        throw new Error('The token\'s payload does not contain "iss" property');
    }
    const isValidSecurityTokenService = tokenPayload.iss.includes('sts') && tokenPayload.iss.includes(tenantId);
    if (!isValidSecurityTokenService) {
        throw new Error("The token's payload contains different security token service");
    }
    // scopes
    if (!tokenPayload.scp) {
        throw new Error('The token\'s payload does not contain "scp" property');
    }
    if (typeof tokenPayload.scp !== 'string') {
        throw new Error("The token's payload scopes are not a string value");
    }
    // expiration
    if (!tokenPayload.exp) {
        throw new Error('The token\'s payload does not contain "exp" property');
    }
    if (typeof tokenPayload.exp !== 'number') {
        throw new Error("The token's payload expiration is not a number value");
    }
    const isValidExpiration = tokenPayload.exp > Math.floor(Date.now() / 1000);
    if (!isValidExpiration) {
        throw new Error("The token's payload contains different expiration");
    }
    const scopesAsArray = tokenPayload.scp.split(' ');
    const hasValidScopes = scopes.every((_scope) => scopesAsArray.includes(_scope));
    if (!hasValidScopes) {
        throw new Error("The token's payload contains different scopes");
    }
}
exports.validateTokenClaims = validateTokenClaims;
function validateB2CTokenClaims(tokenPayload, { clientID, scopes, tenantId, tenantName }) {
    // audience
    if (!tokenPayload.aud) {
        throw new Error('The token\'s payload does not contain "aud" property');
    }
    const isValidAudience = tokenPayload.aud === clientID;
    if (!isValidAudience) {
        throw new Error("The token's payload contains different audience");
    }
    // security token service
    if (!tokenPayload.iss) {
        throw new Error('The token\'s payload does not contain "iss" property');
    }
    const isValidSecurityTokenService = tokenPayload.iss === `https://${tenantName}.b2clogin.com/${tenantId}/v2.0/`;
    if (!isValidSecurityTokenService) {
        throw new Error("The token's issuer is invalid");
    }
    // scopes
    if (!tokenPayload.scp) {
        throw new Error('The token\'s payload does not contain "scp" property');
    }
    if (typeof tokenPayload.scp !== 'string') {
        throw new Error("The token's payload scopes are not a string value");
    }
    // expiration
    if (!tokenPayload.exp) {
        throw new Error('The token\'s payload does not contain "exp" property');
    }
    if (typeof tokenPayload.exp !== 'number') {
        throw new Error("The token's payload expiration is not a number value");
    }
    const isValidExpiration = tokenPayload.exp > Math.floor(Date.now() / 1000);
    if (!isValidExpiration) {
        throw new Error("The token's payload contains different expiration");
    }
    // not before
    if (!tokenPayload.nbf) {
        throw new Error('The token\'s payload does not contain "nbf" property');
    }
    if (typeof tokenPayload.nbf !== 'number') {
        throw new Error("The token's payload expiration is not a number value");
    }
    const isValidNotBefore = tokenPayload.nbf < Math.floor(Date.now() / 1000);
    if (!isValidNotBefore) {
        throw new Error("The token's payload contains invalid not before date");
    }
    const scopesAsArray = tokenPayload.scp.split(' ');
    const hasValidScopes = scopes.every((_scope) => scopesAsArray.includes(_scope));
    if (!hasValidScopes) {
        throw new Error("The token's payload contains different scopes");
    }
}
exports.validateB2CTokenClaims = validateB2CTokenClaims;
